==> liveqa-1.0.0.tgz: package/distribution/event.js <==
'use strict';

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var uuid = require('uuid/v4');
var ApiResource = require('./api_resource.js');
var Cookies = require('js-cookie');

var Event = function () {
  function Event() {
    (0, _classCallCheck3.default)(this, Event);
  }

  (0, _createClass3.default)(Event, null, [{
    key: 'create',
    value: function create(config, name) {
      var params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var properties = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};

      this._config = config;
      var payload = (0, _assign2.default)(params, Event._buildPayload(name, properties));

      ApiResource.post(config, this._resourcePath, payload);
    }

    // private

  }, {
    key: '_buildPayload',
    value: function _buildPayload(name, properties) {
      return {
        name: name,
        properties: properties,
        message_id: uuid(),
        context: this._context,
        timestamp: this._timestamp,
        identifier_id: this._identifierId
      };
    }
  }, {
    key: '_config',
    set: function set(value) {
      this.configuration = value;
    },
    get: function get() {
      return this.configuration;
    }
  }, {
    key: '_resourcePath',
    get: function get() {
      return 'events';
    }
  }, {
    key: '_context',
    get: function get() {
      return {
        library: {
          name: this._config.LIBRARY_NAME,
          language: this._config.LANGUAGE,
          version: this._config.VERSION,
          snippet_version: this._config.SNIPPET_VERSION
        }
      };
    }
  }, {
    key: '_timestamp',
    get: function get() {
      return Math.round(Date.now() / 1000);
    }
  }, {
    key: '_identifierId',
    get: function get() {
      var cookieValue = Cookies.get(this._config.IDENTIFIER_COOKIE_NAME) || uuid();

      Cookies.set(this._config.IDENTIFIER_COOKIE_NAME, cookieValue);

      return cookieValue;
    }
  }]);
  return Event;
}();

module.exports = Event;

==> liveqa-1.1.0.tgz: package/distribution/event.js <==
'use strict';

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var uuid = require('uuid/v4');
var ApiResource = require('./api_resource.js');
var Cookies = require('js-cookie');

var Event = function () {
  function Event() {
    (0, _classCallCheck3.default)(this, Event);
  }

  (0, _createClass3.default)(Event, null, [{
    key: 'create',
    value: function create(config, name) {
      var params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var properties = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};

      this._config = config;
      var payload = (0, _assign2.default)(params, Event._buildPayload(name, properties));

      return ApiResource.post(config, this._resourcePath, payload);
    }

    // private

  }, {
    key: '_buildPayload',
    value: function _buildPayload(name, properties) {
      return {
        name: name,
        properties: properties,
        message_id: uuid(),
        context: this._context,
        timestamp: this._timestamp,
        identifier_id: this._identifierId
      };
    }
  }, {
    key: '_config',
    set: function set(value) {
      this.configuration = value;
    },
    get: function get() {
      return this.configuration;
    }
  }, {
    key: '_resourcePath',
    get: function get() {
      return 'events';
    }
  }, {
    key: '_context',
    get: function get() {
      return {
        library: {
          name: this._config.libraryName,
          language: this._config.language,
          version: this._config.version,
          snippet_version: this._config.snippetVersion
        }
      };
    }
  }, {
    key: '_timestamp',
    get: function get() {
      return Math.round(Date.now() / 1000);
    }
  }, {
    key: '_identifierId',
    get: function get() {
      var cookieValue = Cookies.get(this._config.identifierCookieName) || uuid();

      Cookies.set(this._config.identifierCookieName, cookieValue);

      return cookieValue;
    }
  }]);
  return Event;
}();

module.exports = Event;
